#!/bin/sh

# Webtop Server & K2 Admin (System Console) PostgreSQL DB configuration script
# Copyright (C) 2001 Verity, Inc.

# $1 product (webtop | admin)
# $2 is current platform that the exe's are running on
# $3 is the installation directory

# Command line options:
# -\?,--help				Usage info
# --explain					Explain PostgreSQL config steps
# --trouble					Troubleshooting information
# -h,--host=HOSTNAME 		PostgreSQL server name
# -p,--port=PORT 			PostgreSQL server port number
# -a,--ipadmin=IPADMIN		Admin server machine ip address
# -s,--ipserver=IPSERVER	Webtop server machine ip address
# -d,--database=DATABASE 	Webtop db stem name
# -U,--username=USERNAME 	Webtop db user name
# -W,--password=PASSWORD 	Webtop db password
# -B,--buffers=NUM 			set number of shared buffers (default 64)
# -N,--numprocs=NUM			set max number of backends (1..1024, default 32)
# --start					Start PostgreSQL server 
# --startsmall				Start PostgreSQL server with minimum mem usage 
# --stop					Stop PostgreSQL server
# --status					Status of PostgreSQL server 
# --clean	    			Remove entire Webtop server database

# Hidden options (used when called from installer):
# -g,--go					no confirmation prompt!

# Change path while running this script [WAIT for now - jre]
#PATH=./:/usr/ucb:/usr/bin/:/etc:/usr/bsd:/bin

thisScript=`basename $0`
bindir=`dirname $0`
if [ "$bindir" = "." ]; then
  bindir=`pwd`
fi

# whoami: solaris=/usr/ucb/, hpux=/bin/, cygwin=/usr/bin/
whocmd="/usr/ucb/whoami"
#whocmd=`which whoami`
config_user=`$whocmd`
# Check if user is root as PostgreSQL cannot be run as root
if [ "${config_user}" = "root" ]; then
  echo ""
  echo "Cannot run this configuration script as root because"
  echo "PostgreSQL cannot be run as root. Please restart this"
  echo "script as the database super-user (which cannot be root)"
  echo "by typing:"
  echo ""
  echo "${bindir}/${thisScript} $@"
  echo ""
  echo "Exiting..."
  echo ""
  exit 1
fi

# grep command - we want to grep for multiple strings "-e" option
grepcmd=/usr/xpg4/bin/grep
# command to get ip address of this server:
arpcmd=/usr/sbin/arp
pscmd=/bin/ps
hname=`hostname`
domainname=""
if [ -x /bin/domainname ]; then
  domainname=`domainname`
  domainname=".${domainname}"
fi

# Look for PostgreSQL environment variables
if [ "$PGHOST" != "" ]; then
  dbservername=$PGHOST
  unset PGHOST
fi
if [ "$PGPORT" != "" ]; then
  dbport=$PGPORT
  unset PGPORT
fi

usage=
explain=
info=
clean=
go=
action=
nbufs=64
nprocs=32

webtop_dir=
platform=
dest_dir=

############################
# Parse command line options
############################
while [ $# -gt 0 ]; do
    case "$1" in
    --help|-\?)
        usage=t
        ;;
    --explain)
        explain=t
        ;;
    --trouble)
        info=t
        ;;
    --clean)
        clean=t
        ;;
    --start)
        action=start
        ;;
    --startsmall)
        nbufs=16
        nprocs=8
        action=start
        ;;
    --stop)
        action=stop
        ;;
    --status)
        action=status
        ;;
    --go|-g)
        go=t
        ;;
    --host|-h)
        dbservername="$2"
        shift;;
        -h*)
            dbservername=`echo $1 | sed 's/^-h//'`
            ;;
        --host=*)
            dbservername=`echo $1 | sed 's/^--host=//'`
            ;;
    --port|-p)
        dbport="$2"
        shift;;
        -p*)
            dbport=`echo $1 | sed 's/^-p//'`
            ;;
        --port=*)
            dbport=`echo $1 | sed 's/^--port=//'`
            ;;
    --ipadmin|-a)
        ipadmin="$2"
        shift;;
        -a*)
            ipadmin=`echo $1 | sed 's/^-a//'`
            ;;
        --ipadmin=*)
            ipadmin=`echo $1 | sed 's/^--ipadmin=//'`
            ;;
    --ipserver|-s)
        ipserver="$2"
        shift;;
        -s*)
            ipserver=`echo $1 | sed 's/^-s//'`
            ;;
        --ipserver=*)
            ipserver=`echo $1 | sed 's/^--ipserver=//'`
            ;;
    --database|-d)
        dbname="$2"
        shift;;
        -d*)
            dbname=`echo $1 | sed 's/^-p//'`
            ;;
        --database=*)
            dbname=`echo $1 | sed 's/^--port=//'`
            ;;
    --username|-U)
        dbuser="$2"
        shift;;
        -U*)
            dbuser=`echo $1 | sed 's/^-U//'`
            ;;
        --username=*)
            dbuser=`echo $1 | sed 's/^--username=//'`
            ;;
    --password|-W)
        dbpasswd="$2"
        shift;;
        -W*)
            dbpasswd=`echo $1 | sed 's/^-W//'`
            ;;
        --password=*)
            dbpasswd=`echo $1 | sed 's/^--password=//'`
            ;;
    --buffers|-B)
        nbufs="$2"
        shift;;
        -B*)
            nbufs=`echo $1 | sed 's/^-B//'`
            ;;
        --buffers=*)
            nbufs=`echo $1 | sed 's/^--buffers=//'`
            ;;
    --numprocs|-N)
        nprocs="$2"
        shift;;
        -N*)
            nprocs=`echo $1 | sed 's/^-N//'`
            ;;
        --numprocs=*)
            nprocs=`echo $1 | sed 's/^--numprocs=//'`
            ;;
    -*)
        echo "$thisScript: invalid option: $1"
        echo "Try -? for help."
        exit 1
        ;;
     *)
        if [ "${webtop_dir}" = "" ]; then
            webtop_dir=$1
        elif [ "${platform}" = "" ]; then
            platform=$1
        elif [ "${dest_dir}" = "" ]; then
            dest_dir=$1
        fi
        ;;
    esac
    shift;
done

###############################
# Default destination directory
###############################
# Precedence order:
#    1) command_line
#    2) this script's defaults
# this script resides in ${dest_dir}/_$platform/bin (aka bindir), so:
cddotdot=`dirname $bindir`
if [ "${dest_dir}" = "" ]; then
    #dest_dir=$HOME/verity
    dest_dir=`dirname $cddotdot`
    if [ "${dest_dir}" = "." ]; then
        dest_dir=`pwd`
    fi
fi

# We should be able to determine the platform here as well!!
# leave in the platform determination code below for now - jre
if [ "${platform}" = "" ]; then
    platform=`basename $cddotdot | sed 's/^_//`
fi

# Figure out which product we are using Webtop or Admin
# Let's see if both are installed?
iswebtop=
isadmin=
if [ -d ${dest_dir}/webtop ]; then
  iswebtop=t
fi
if [ -d ${dest_dir}/k2admin ]; then
  isadmin=t
fi

# Figure out which one to use
if [ "${webtop_dir}" = "" ]; then
  if [ "$usage" ]; then
    webtop_dir=webtop
  elif [ "$iswebtop" -a "$isadmin" ]; then
    echo ""
    echo "Please select the product you would like to use on the"
    echo "command line [webtop | admin]. For more information, type:"
    echo ""
    echo "  ${bindir}/${thisScript} --help"
    echo ""
    exit 1  
  elif [ "$iswebtop" ]; then
    webtop_dir=webtop
  elif [ "$isadmin" ]; then
    webtop_dir=admin    
  fi
fi

productalias=${webtop_dir}
if [ "${productalias}" = "webtop" ]; then
  wbtp=${productalias}20;
  wbtpdb_desc="Webtop Server DB - PostgreSQL V7.0.3"
  productname="Webtop"
elif [ "${productalias}" = "admin" ]; then
  webtop_dir=k2${productalias}
  wbtp=k2${productalias}10;
  wbtpdb_desc="K2 System Console server DB - PostgreSQL V7.0.3"
  productname="K2 System Console"
else
  echo ""
  echo "Error, the product you specified is incorrect (${webtop_dir})."
  echo "Please select the product you would like to use on the"
  echo "command line [webtop | admin]. For more information, type:"
  echo ""
  echo "  ${bindir}/${thisScript} --help"
  echo ""
  exit 1  
fi

##############################
# PostgreSQL Database defaults
##############################
# Precedence order:
#    1) command_line options
#    2) defs.jnc
#    3) this script's defaults

# Read defs.jnc or poolman.props
defs=${dest_dir}/${webtop_dir}/server/ssi/defs.jnc
pmprops=${dest_dir}/${webtop_dir}/server/WEB-INF/lib/poolman.props
params=
if [ -f $defs ]; then
  vc_database=`grep VC_DataBase $defs | grep -v VC_DataBaseDriver`
  #echo $vc_database
  # public static final String VC_DataBase="jdbc:postgresql://localhost:5432/VerityPortalOne_Server?user=verity&password=verity";
  usepoolman=`echo $vc_database | grep poolman`
  
  dbinfo=`echo $vc_database | sed 's/.*"jdbc:postgresql:\/\/\(.*\)";/\1/'`
  #echo $dbinfo
  # localhost:5432/VerityWebtop_Server?user=verity&password=verity
  # localhost:5432/Verity_Administration?user=verity&password=verity
  
  #Test if its PostgreSQL
  if [ "${vc_database}" != "${dbinfo}" ]; then
    params=`echo $dbinfo | sed 's/\(.*\):\(.*\)\/\(.*\)_.*?user=\(.*\)&password=\(.*\)/\1 \2 \3 \4 \5/'`
    #echo $params
    # localhost 5432 VerityWebtop verity verity
  # See if we're using poolman?
  elif [ "$usepoolman" ]; then
      echo "WARNING: the ${productname} is setup to use the PoolMan virtual jdbc driver."
      echo "  Currently, this script cannot determine the database values"
      echo "  PoolMan is using. Please ensure the values you specify match those"
      echo "  selected when you installed the ${productname} server."
      echo ""
  # Oops, probably setup for Oracle or a typo exists
  else
    echo "WARNING: the ${productname} server defs.jnc file does not use PostgreSQL."
    echo "  Your ${productname} server Java Server Pages will not be able to use these"
    echo "  configuration settings. Please update the following the file:"
    echo "  $defs"
    echo ""
  fi
fi
if [ "$dbservername" = "" ]; then
    dbservername=`echo $params | awk '{print $1}'`
    if [ "$dbservername" = "" ]; then
        dbservername=$hname
        dbservername=${dbservername}$dommainname
    fi
fi
if [ "$dbport" = "" ]; then
    dbport=`echo $params | awk '{print $2}'`
    if [ "$dbport" = "" ]; then
        dbport=5432
    fi
fi
if [ "$dbname" = "" ]; then
    dbname=`echo $params | awk '{print $3}'`
    if [ "$dbname" = "" ]; then
        if [ "${webtop_dir}" = "webtop" ]; then
            dbname=VerityWebtop
        else
            dbname=Verity        
        fi
    fi
fi
if [ "$dbuser" = "" ]; then
    dbuser=`echo $params | awk '{print $4}'`
    if [ "$dbuser" = "" ]; then
        dbuser=verity
    fi
fi
if [ "$dbpasswd" = "" ]; then
    dbpasswd=`echo $params | awk '{print $5}'`
    if [ "$dbpasswd" = "" ]; then
        dbpasswd=verity
    fi
fi
if [ "$ipserver" = "" ]; then
    ipserver=`$arpcmd $hname | tr -d '()' | awk '{print $2}'`
fi
if [ "$ipadmin" = "" ]; then
    ipadmin=`$arpcmd $hname | tr -d '()' | awk '{print $2}'`
fi

###################
# Usage information
###################
if [ "$usage" ]; then    
    echo "$thisScript configures/starts/stops the ${productname} Server Built-in"
    echo "database (PostgreSQL)."
    echo ""
    echo "usage:"
    echo "  $thisScript [options] [webtop|admin] [platform] [install dir]"
    echo ""
    echo "options:"
    echo "  -?, --help                 show this information"
    echo "  --explain                  Explain PostgreSQL config steps"
    echo "  --trouble                  Troubleshooting information"
    echo "  -h, --host=HOSTNAME        PostgreSQL server host [$dbservername]"
    echo "  -p, --port=PORT            PostgreSQL server port [$dbport]"
    echo "  -a, --ipadmin=IPADMIN      Webtop Admin machine ip # [$ipadmin]"
    echo "  -s, --ipserver=IPSERVER    ${productname} Server machine ip # [$ipserver]"
    echo "  -d, --database=DATABASE    ${productname} database prefix name [$dbname]"
    echo "  -U, --username=USERNAME    ${productname} database username [$dbuser]"
    echo "  -W, --password=PASSWORD    ${productname} databsae password [$dbpasswd]"
    echo "  -B, --buffers=NUM          PostgreSQL # of shared buffers [$nbufs]"
    echo "  -N, --numprocs=NUM         PostgreSQL max # of backends [$nprocs]"
    echo "  --clean                    Remove all PostgreSQL database(s)"
    echo "  --status                   Status of PostgreSQL server"
    echo "  --stop                     Stop PostgreSQL server"
    echo "  --start                    Start PostgreSQL server"
    echo "  --startsmall               Start PostgreSQL server (minimum mem usage)"
    echo ""
    exit 0
fi

###########################
# logging of what's happen'
###########################
log=$dest_dir/version/$wbtp/configdb.log
if [ ! -d $dest_dir/version/$wbtp ]; then
  mkdir -p $dest_dir/version/$wbtp
fi

if [ -f $log ]; then
  if [ ! -w $log ]; then
    echo "You do not have permission to write to log file."
    echo "Modify permissions and rerun this script." 
    echo "LOG FILE: $log"
    exit 1 
  fi
fi

echo "$@" >> $log
date >> $log
uname -a >> $log
echo >> $log

###################################
### Find which OS we are running on
###################################
ostype=`uname -s`
osver=`uname -r`

# Determine how we display a prompt:
#case "$ostype" in
#  AIX*|HP-UX*) usehpecho="yes"; PROMPT="echo >\c"; ;;
#  *)           usehpecho="no";  PROMPT="echo -n >" ;;
#esac

# Check for echo -n vs echo \c
if echo '\c' | grep -s c >/dev/null 2>&1
then
    usehpecho="no"
    PROMPT="echo -n >"
else
    usehpecho="yes"
    PROMPT="echo >\c"
fi

# FIXME - determine if we really need the code below 
# as we figured out the platform from the bindir above!!
if [ "$platform" = "" ]; then
sun=sun441       ;  sun_desc="SPARC SunOS v4.1.3"
sol=solaris      ;  sol_desc="SPARC SunOS v2.5.1"
ssol26=ssol26    ;  ssol26_desc="SPARC SunOS v2.6, v7.0"
osf=aosf32       ;  osf_desc="DEC Alpha OSF1 v3.2"
osf40=aosf40     ;  osf40_desc="DEC Alpha OSF1 v4.0b, v4.0d"
svr4=isvr4       ;  svr4_desc="Intel SVR4 (AT&T GIS)"
hpux=hpux        ;  hpux_desc="HP/UX v9.0.4"
hpux10=hpux10    ;  hpux10_desc="HP/UX v10.10, v10.20"
hpux11=hpux11    ;  hpux11_desc="HP/UX v11"
rs6k=rs6k41      ;  rs6k_desc="RS6000 IBM AIX v4.1.4, v4.2"
#rs6k=rs6k43      ;  rs6k_desc="RS6000 IBM AIX v4.3"
dgux=dgux        ;  dgux_desc="DG/UX 5.4R3.10"
mips=mipsabi     ;  mips_desc="MIPS SVR4 ABI Compliant"
irix=irix        ;  irix_desc="SGI IRIX v5.3"
irix62=irix62    ;  irix62_desc="SGI IRIX v6.2, v6.3"
sinix=sinix      ;  sinix_desc="SINIX v5.43"
ilnx21=ilnx21    ;  ilnx21_desc="Red Hat Linux 6.0"
sco=scoodt       ;  sco_desc="SCO OpenServer 5.0 or later"

case "$ostype" in
  AIX*)     platform="rs6k41"; ;;
  IRIX*)    platform="irx"; ;;
  *abi*)    platform="mipsabi"; ;;
  UNIX_SV*) platform="isvr4"; ;;
  SunOS*)   platform="s";    ;;
  HP-UX*)   platform="hp";  ;;
  OSF*)     platform="osf";  ;;
  dgux*)    platform="dgux"; ;;
  SCO*)     platform="scoodt"; ;;
  SINIX*)   platform="sinix"; ;;
  FreeB*)   platform="fbsd"; ;;
  Linux*)   platform="ilnx21"; ;;
  *)        platform="cray II"; ;;
esac

platlater=" or later"
if [ "$platform" = "s" ]; then
    osver=`uname -r | cut -c1-1`
    if [ "$osver" = "5" ]; then
        osminor=`uname -r | cut -c3-3`;
        if [ "$osminor" = "5" ]; then
            platform="solaris"
            platlater=""
        elif [ "$osminor" = "6" ] || [ "$osminor" = "7" ]; then
            platform="ssol26"
        elif [ "$osminor" = "8" ]; then
            platform="SPARC Solaris 8.0"
        else
            platform="?"
        fi 
   elif [ "$osver" = "4" ]; then
        platform="sun441"
   else
        platform="?"
   fi
fi

if [ "$platform" = "hp" ]; then
    osver=`uname -r | cut -c3-4`
    if [ "$osver" = "11" ]; then
        platform="hpux11"
    elif [ "$osver" = "10" ]; then
        platform="hpux10"
    elif [ "$osver" = "09" ]; then
        platform="hpux"
    else
        platform="?"
    fi
fi

if [ "$platform" = "osf" ]; then
    osver=`uname -r | cut -c2-2`
    if [ "$osver" = "3" ]; then
        platform="aosf32"
    elif [ "$osver" = "4" ]; then
        platform="aosf40"
    else
        platform="?"
    fi
fi

if [ "$platform" = "irx" ]; then
    osver=`uname -r | cut -c1-1`
    if [ "$osver" = "5" ]; then
        platform="irix"
    elif [ "$osver" = "6" ]; then
        platform="irix62"
    else
        platform="?"
    fi
fi

if [ "$platform" = "ilnx21" ]; then
    platform="ilnx21"
fi

exeloop="notdone"
while [ "$exeloop" != "done" ]; do
  if [ "$platform" != "?" ]; then
    ## This is to echo the platform back to the user ##
    if [ "$usehpecho" = "yes" ]; then
       echo "Is this configuration script running on \c" | tee -a $log
    else
       echo -n "Is this configuration script running on " | tee -a $log
    fi

    if   [ "$platform" =  "aosf32"  ];  then platdesc="DEC Alpha OSF1 3.2";
    elif [ "$platform" =  "aosf40"  ];  then platdesc="DEC Alpha OSF1 4.0c";
    elif [ "$platform" =  "dgux"    ];  then platdesc="DG/UX 5.4R3.10";
    elif [ "$platform" =  "hpux"    ];  then platdesc="HP/UX 9.0.4";
    elif [ "$platform" =  "hpux10"  ];  then platdesc="HP/UX 10.10, 10.20";
    elif [ "$platform" =  "hpux11"  ];  then platdesc="HP/UX 11";
    elif [ "$platform" =  "irix"    ];  then platdesc="SGI IRIX 5.3";
    elif [ "$platform" =  "irix62"  ];  then platdesc="SGI IRIX 6.2, 6.3";
    elif [ "$platform" =  "irixn32" ];  then platdesc="SGI IRIX 6.2 (n32)";
    elif [ "$platform" =  "isvr4"   ];  then platdesc="Intel SVR4 (AT&T GIS)";
    elif [ "$platform" =  "mipsabi" ];  then platdesc="MIPS SVR4 ABI Compliant";
    elif [ "$platform" =  "rs6k41"  ];  then platdesc="IBM RS6000 AIX 4.1.4, 4.2.0";
    elif [ "$platform" =  "scoodt"  ];  then platdesc="SCO OpenServer 5.0";
    elif [ "$platform" =  "sinix"   ];  then platdesc="SINIX 5.43";
    elif [ "$platform" =  "solaris" ];  then platdesc="SPARC Solaris 2.5.1";
    elif [ "$platform" =  "ssol26"  ];  then platdesc="SPARC Solaris 2.6, 7.0";
    elif [ "$platform" =  "ssol23"  ];  then platdesc="SPARC Solaris 2.3";
    elif [ "$platform" =  "sun441"  ];  then platdesc="SPARC SunOS 4.1.3";
    elif [ "$platform" =  "fbsd"    ];  then platdesc="FreeBSD 2.2.6";
    elif [ "$platform" =  "ilnx21"  ];  then echo -n "Red Hat Linux 6.0 or later";
    else platdesc="$platform";
    fi

    if [ "$usehpecho" = "yes" ]; then
        echo "$platdesc$platlater? [y/n] \c" | tee -a $log
    else 
        echo -n "$platdesc$platlater? [y/n] " | tee -a $log
    fi

    read valos
    valos=`echo $valos | tr 'A-Z' 'a-z'`
    echo $valos >> $log

    case "$valos" in
      y|yes|"") exeloop="done"
                       ;;
      #"")              exeloop="notdone" ;;
      *)               platform="?";
                       ;;
    esac

  else
    if [ "$platform" = "?" ]; then
        echo "" | tee -a $log
        echo "Please enter the platform that this script is running on." | tee -a $log
        echo "" | tee -a $log
        echo "  Platform   Description" | tee -a $log
        echo "  --------   -----------" | tee -a $log
        echo "  solaris    SPARC Solaris v2.5.1" | tee -a $log
        echo "  ssol26     SPARC Solaris v2.6, v7.0" | tee -a $log
        echo "  rs6k41     RS6000 IBM AIX v4.1.4, v4.2" | tee -a $log
        echo "  hpux10     HP/UX v10.10, v10.20" | tee -a $log
        echo "  hpux11     HP/UX v11" | tee -a $log
        echo "  aosf40     DEC Alpha OSF1 v4.0c" | tee -a $log
        echo "  irix62     SGI IRIX v6.2, v6.3" | tee -a $log
        echo "  irixn32    SGI IRIX v6.2 (n32)" | tee -a $log
        echo "  fbsd       FreeBSD v2.2.6" | tee -a $log
        echo "  ilnx21     Red Hat Linux 6.0 or later" | tee -a $log
        echo ""  | tee -a $log

        $PROMPT | tee -a $log
        read platform
        echo $platform >> $log

        case "$platform" in
            ssol26|solaris|rs6k41|hpux10|hpux11|aosf40|irix62|irixn32|fbsd|ilnx21) exeloop="done"; ;;
          "") echo "aborting..." | tee -a $log; echo; exit 1 ;;
          *) echo "$platform invalid . . . exiting." | tee -a $log; exit 1;    ;;
        esac
    fi
  fi
done
fi

#######################
# Installation Settings
#######################
# Webtop Server Installation:
# $2/$webtop_dir/dbase - for the pgsql data directory
# $2/$webtop_dir/pgsql/pgdb.sql,pgvalue.sql
if [ "$PGDATA" != "" ]; then
  vpwdb=$PGDATA
  unset PGDATA
else
  vpwdb=${dest_dir}/${webtop_dir}/dbase
fi
vpwpg=${dest_dir}/${webtop_dir}/pgsql

# PostgreSQL Installation:
# $2/$1/bin - contents from pgsql/bin
# $2/$1/lib - contents from pgsql/lib
pgbin=${dest_dir}/_${platform}/bin
if [ "$PGLIB" != "" ]; then
  pglib=$PGLIB
  unset PGLIB
else
  pglib=${dest_dir}/_${platform}/lib
fi
pglog=${dest_dir}/_${platform}/log
#usage: postmaster [options]
#        -B nbufs        set number of shared buffers
#        -D datadir      set data directory
#        -S              silent mode (disassociate from tty)
#        -a system       use this authentication system
#        -b backend      use a specific backend server executable
#        -d [1-5]        set debugging level
#        -i              listen on TCP/IP sockets as well as Unix domain socket
#        -N nprocs       set max number of backends (1..1024, default 32)
#        -n              don't reinitialize shared memory after abnormal exit
#        -o option       pass 'option' to each backend servers
#        -p port specify port for postmaster to listen on
#        -s              send SIGSTOP to all backend servers if one dies
pgopts="-i -S -B ${nbufs} -N ${nprocs} -p ${dbport}"
pgstart="${pgbin}/pg_ctl -D ${vpwdb} -p ${pgbin}/postmaster -o \"${pgopts}\" start"
pgstop="${pgbin}/pg_ctl -D ${vpwdb} -m smart stop"

# Old way was to grep for the process, however this failed when
# the installation path was long
#echo "DEBUG: ps -e | ${grepcmd} -e postmast -e postgres | ${grepcmd} -v grep | awk '{print 1}'"
#debug=`ps -e`
#echo "DEBUG ps -e: $debug"
#debug=`ps -e | ${grepcmd} -e postmast -e postgres | ${grepcmd} -v grep`
#echo "DEBUG pipe grep: $debug"
#pmpid=`${pscmd} -ef | ${grepcmd} -e postmast -e postgres | ${grepcmd} "p $dbport" | ${grepcmd} -v grep | awk '{print $2}'`
pmpid=
if [ -f ${vpwdb}/postmaster.pid ]; then
	pmpid=`cat ${vpwdb}/postmaster.pid`
fi
#echo "DEBUG pmpid: $pmpid"

if [ "$LD_LIBRARY_PATH" != "" ]; then
    LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${pglib}
else
    LD_LIBRARY_PATH=${pglib}
fi
export LD_LIBRARY_PATH

PATH=${PATH}:${pgbin}
export PATH

# Database configuration parameters
dbserver="-h ${dbservername} -p ${dbport}"

# Server, Logging and Statistics DB names
if [ "${webtop_dir}" = "webtop" ]; then
  dbnamesrv="${dbname}_Server"
  dbnamelog="${dbname}_Logging"
  dbnamesta="${dbname}_Statistics"
else
  dbnamesrv="${dbname}_Administration"
  dbnamelog=
  dbnamesta=
fi

#############################
# Troubleshooting information
#############################
if [ "$info" ]; then
  echo ""
  echo "Q) I cannot connect from the Webtop MMC-SnapIn Administration tool"
  echo "   to the Webtop Server Built-In database (PostgreSQL), what should I"
  echo "   check?"
  echo "A) Verify that PostgreSQL is running, by typing:"
  echo "      $pgbin/$thisScript --status webtop"
  echo "   Verify the PostgreSQL permissions file allows the Webtop"
  echo "   administration machine to connect. To do so, verify the following"
  echo "   file allows access. See the associated '.orig' and '.pword' files"
  echo "   for more information and examples:"
  echo "      ${vpwdb}/pg_hba.conf"
  echo ""
  echo "Q) How do I start/stop the ${productname} Server Built-In database (PostgreSQL)?"
  echo "A) To start the PostgreSQL database server, type:"
  echo "      $pgbin/$thisScript --start $productalias"
  echo "   To stop the PostgreSQL database server:"
  echo "      $pgbin/$thisScript --stop $productalias"
  echo ""
  echo "Q) What can I do if I get 'IpcMemoryCreate: shmget failed' or "
  echo "   'ShmemCreate: cannot create region' error messages when I try to"
  echo "   run the ${productname} Server Built-In database (PostgreSQL)?"
  echo "A) PostgreSQL makes use of your system's shared memory and semaphores."
  echo "   Upon startup, it allocates default sizes for these resources which "
  echo "   may exceed your system's current configuration. You may either"
  echo "   increase your system's configuration settings (consult your system's"
  echo "   documentation on how to perform this task) or try starting PostgreSQL"
  echo "   with the minimum required resource sizes. To do so, type:"  
  echo "      $pgbin/$thisScript --startsmall $productalias"
  echo "   Depending on the ${productname} Server user load, you may need to increase"
  echo "   your system's shared memory and semaphore sizes."
  echo ""
  echo "Q) How can I run PostgreSQL command line utilities directly?"
  echo "A) Simply type the desired command (exmaples below). To assist in "
  echo "   running these utilities you may want to set the following "
  echo "   environment variables:"
  echo "      PGHOST=$dbservername"
  echo "      PGPORT=$dbport"
  echo "      PGDATA=$vpwdb"
  echo "      PGLIB=$pglib"
  echo "   And add the following directory to your PATH:"
  echo "      $pgbin"
  echo ""   
  echo "   To remove the ${productname} server database(s), type:"
  echo "      % dropdb -h $dbservername -p $dbport $dbnamesrv"
  if [ "${webtop_dir}" = "webtop" ]; then
    echo "      % dropdb -h $dbservername -p $dbport $dbnamelog"
    echo "      % dropdb -h $dbservername -p $dbport $dbnamesta"
  fi
  echo "   To remove the Webtop server database user, type:"
  echo "      % dropuser -h $dbservername -p $dbport $dbuser"
  echo "   To shutdown the PostgreSQL server, type:"
  echo "      % pg_ctl -D $vpwdb -m smart stop"
  echo ""
  echo "Q) Is there a website for more troubleshooting information on PostgreSQL?"
  echo "A) Yes, try:"
  echo "      http://www.postgresql.org/users-lounge/docs/7.0/admin/trouble.htm"
  echo ""
  echo "Q) Who else can help me with my problem and/or question?"
  echo "A) Contact Verity Tech support: tech-support@verity.com"
  echo ""
  exit 0
fi

#############################
# Explain Configuration steps
#############################
if [ "$explain" ]; then
  echo ""
  echo "This describes the steps taken by this script when"
  echo "configuring the Built-in database (PostgreSQL)." 
  echo "This configuration script will be called during the ${productname}"
  echo "installation. However, if problems occur then they must be"
  echo "resolved and this script run again to setup the database."
  echo "To resolve problems follow the sequence of steps outlined"
  echo "below to look for possible sources of error."
  echo ""
  echo "All commands below (indicated by a shell prompt, '%') are located"
  echo "in your installation bin directory:"
  echo "    $pgbin"
  echo "You may want to place this directory in your PATH environment"
  echo "variable to save on typing."
  echo ""
  echo "[STEP 1]"
  echo "Initialize the PostgreSQL ${productname} server database:"
  echo "% initdb -D $vpwdb"
  echo ""
  echo "[STEP 2]"
  echo "Using any text editor, update the PostgreSQL permissions file:"
  echo "    ${vpwdb}/pg_hba.conf"
  echo "to allow TCP/IP connections from this server to the database. This"
  echo "is necessary for the commands as specified below. For example, add"
  echo "the following line, replacing 'your.server.ip.address' with the "
  echo "appropriate value for your server:"
  echo ""
  echo "host    all   your.server.ip.address  255.255.255.255    trust"
  echo ""
  echo "[STEP 3]"
  echo "Start the PostgreSQL database server ('-S' means silent mode no output,"
  echo "'-B 16 -N 8' means use minimum memory footprint [Note: you may need to"
  echo "increase your system's shared memory and semaphore sizes depending"
  echo "on your user load. PostgreSQL defaults to -B 64 -N 32]):"
  echo "% pg_ctl -D $vpwdb \\ "
  echo "  -p ${pgbin}/postmaster \\ "
  echo "  -o '-i -S -p $dbport -B 16 -N 8' start"
  echo ""
  echo "Alternatively, to capture output in a log file, you can use:"
  echo "% postmaster -i -B 16 -N 8 -D $vpwdb \\ "
  echo "  -p $dbport > ${pglog}/vpwpgdb.log 2>&1 &"
  echo ""
  echo "[STEP 4]"
  echo "Create the ${productname} server database user:"
  echo "% createuser -d -A $dbserver $dbuser"
  echo ""
  echo "[STEP 5]"
  if [ "${webtop_dir}" = "webtop" ]; then
    echo "Create the ${productname} server databases; Server, Logging and Statistics:"
    echo "% createdb $dbserver -U $dbuser $dbnamesrv '${productname} Server DB'"
    echo "% createdb $dbserver -U $dbuser $dbnamelog '${productname} Logging DB'"
    echo "% createdb $dbserver -U $dbuser $dbnamesta '${productname} Statistics DB'"
  else
    echo "Create the ${productname} server database:"
    echo "% createdb $dbserver -U $dbuser $dbnamesrv '${productname} Server DB'"
  fi
  echo ""
  echo "[STEP 6]"
  echo "Populate the ${productname} server database:"
  echo "% psql $dbserver -f ${vpwpg}/pgdb.sql $dbnamesrv $dbuser"
  echo "% psql $dbserver -f ${vpwpg}/pgvalues.sql $dbnamesrv $dbuser"
  echo ""
  echo "[STEP 7]"
  echo "Update the ${productname} server database password information."
  echo "% sqlcmd=\"update pg_shadow set passwd='$dbpasswd' where usename='$dbuser'\""
  echo "% psql $dbserver -c '\$sqlcmd' $dbnamesrv"
  echo ""
  echo "[STEP 8]"
  echo "This configuration script sets the PostgreSQL permissions file to"
  echo "allow connections from any ip address. If this is not acceptable"
  echo "then, using any text editor, update the PostgreSQL permissions file:"
  echo "    ${vpwdb}/pg_hba.conf"
  echo "to allow TCP/IP connections from the ${productname} Java Server Pages"
  if [ "${webtop_dir}" = "webtop" ]; then
    echo "as well as the Webtop MMC snap-in Administration tool. "
  fi
  echo "Thus, the contents of pg_hba.conf might be similar to the following:"
  echo ""
  echo "local   all                                              trust"
  echo "host    all   your.server.ip.address  255.255.255.255    password"
  echo "host    all   your.admin.ip.address   255.255.255.255    password" 
  echo ""
  echo "To allow additional connections from other ${productname} Servers and/or" 
  echo "Administration tools, either add new ip addresses or modify the"
  echo "mask (4th parameter) from 255.255.255.255 to 255.255.255.0, for"
  echo "example."
  echo ""
  exit 0
fi

################################
# Cleanup previous configuration
################################
if [ "$clean" ]; then
  clean=NO
  confirm=YesImVeritySure
  echo "Are you sure you want to completely remove all PostgreSQL " | tee -a $log
  echo "database(s) including the ${productname} server databases?" | tee -a $log
  echo "" | tee -a $log
  if [ "$usehpecho" = "yes" ]; then
    echo "Type '$confirm' to continue: \c" | tee -a $log
  else 
    echo -n "Type '$confirm' to continue: " | tee -a $log
  fi
  read clean
  if [ "$clean" = "$confirm" ]; then
    # make it easy on ourselves :-)
    cp -f ${vpwdb}/pg_hba.conf.trust ${vpwdb}/pg_hba.conf

    # Is postgres already running?
    if [ "${pmpid}" = "" ]; then
      eval $pgstart
    fi
    ${pgbin}/dropdb $dbserver $dbnamesrv
    if [ $? -eq 0 ]; then
      if [ "${webtop_dir}" = "webtop" ]; then
        ${pgbin}/dropdb $dbserver $dbnamelog
        ${pgbin}/dropdb $dbserver $dbnamesta
      fi
      ${pgbin}/dropuser $dbuser
      eval $pgstop
      rm -f  ${vpwdb}/PG_VERSION
      rm -f  ${vpwdb}/postmaster.*
      rm -Rf ${vpwdb}/base
      rm -Rf ${vpwdb}/pg_*
    else
      echo "Problem dropping database ($dbnamesrv)." | tee -a $log
      echo "Aborting remove request." | tee -a $log
      exit 1
    fi
  else
    echo "Aborting remove request." | tee -a $log
  fi
  exit 0
fi

###############################
# Stop/Start PostgreSQL server
###############################
if [ "$action" ]; then
  doit=t
  if [ "$action" = "start" ]; then
    # Is postgres already running?
    if [ "${pmpid}" = "" ]; then
      action=$pgstart
    else
      action="PostgreSQL already started."
      doit=
    fi
  elif [ "$action" = "stop" ]; then
    # Is postgres already running?
    if [ "${pmpid}" ]; then
      action=$pgstop
    else
      action="PostgreSQL already stopped."
      doit=
    fi    
  elif [ "$action" = "status" ]; then
      action="${pgbin}/pg_ctl -D ${vpwdb} status"
  fi
  echo "Performing PostgreSQL action:" | tee -a $log
  echo $action | tee -a $log
  if [ "$doit" ]; then
    eval $action
  fi
  exit 0
fi

################
# Splash screen
################
if [ ! "$go" ]; then
  clear
  echo '' | tee -a $log
  echo '$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$' | tee -a $log
  echo '$$$             Verity              $$$' | tee -a $log
  echo '$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$' | tee -a $log
fi
echo "" | tee -a $log
echo '*** Configuration script for '$wbtpdb_desc' ***' | tee -a $log

###########################
###  CONFIGURE PostgreSQL
###########################
# Confirm selections if UI
if [ ! "$go" ]; then
  echo "" | tee -a $log
  echo "Configuration settings:" | tee -a $log
  echo "    Product                      = $productname" | tee -a $log
  echo "    Installation platform        = $platform" | tee -a $log
  echo "    Installation directory       = ${dest_dir}" | tee -a $log
  echo "    PostgreSQL server host       = $dbservername" | tee -a $log
  echo "    PostgreSQL server port       = $dbport" | tee -a $log
  echo "    PostgreSQL # of buffers      = $nbufs" | tee -a $log
  echo "    PostgreSQL # of backends     = $nprocs" | tee -a $log
  if [ "${webtop_dir}" = "webtop" ]; then
    echo "    Webtop Admin machine ip #    = $ipadmin" | tee -a $log
  fi
  echo "    ${productname} Server machine ip #   = $ipserver" | tee -a $log
  echo "    ${productname} Server database       = $dbnamesrv" | tee -a $log
  if [ "${webtop_dir}" = "webtop" ]; then
    echo "    ${productname} Logging database      = $dbnamelog" | tee -a $log
    echo "    ${productname} Statistics database   = $dbnamesta" | tee -a $log
  fi
  echo "    ${productname} database username     = $dbuser" | tee -a $log
  echo "    ${productname} database password     = $dbpasswd" | tee -a $log
  if [ "$usehpecho" = "yes" ]; then
    echo "OK [yes]? \c" | tee -a $log
  else 
    echo -n "OK [yes]? " | tee -a $log
  fi
  read item
  echo $item >> $log
  case "$item" in
    y|yes|"") echo "Confirmed." | tee -a $log; ;;
    *) echo "Exiting..."  | tee -a $log; exit 1; ;;
  esac
fi

# Initialize the database
# If they are already using postgresql perhaps we should do an initlocation???
# datadir MUST be absolute (pgsql does not handle "." and "..")
#Usage:
#  initdb [options] datadir
#Options:
# [-D, --pgdata] <datadir>     Location for this database
#  -W, --pwprompt              Prompt for a password for the new superuser's
#  -i, --sysid <sysid>         Database sysid for the superuser
#Less commonly used options:
#  -L, --pglib <libdir>        Where to find the input files
#  -t, --template              Re-initialize template database only
#  -d, --debug                 Generate lots of debugging output
#  -n, --noclean               Do not clean up after errors
# http://www.postgresql.org/docs/postgres/app-initdb.htm
if [ ! -f ${vpwdb}/PG_VERSION ]; then
  echo "" | tee -a $log
  echo "Initializing new ${productname} server database (PostgreSQL):" | tee -a $log
  echo "location: ${vpwdb}" | tee -a $log
  echo ${pgbin}/initdb -D ${vpwdb} | tee -a $log
  # Create the dbase directory if it does not exist
  if [ ! -d ${vpwdb} ]; then
    if [ ! -d ${dest_dir}/${webtop_dir} ]; then  
      mkdir ${dest_dir}/${webtop_dir}
    fi
    mkdir ${vpwdb}
  fi
  ${pgbin}/initdb -D ${vpwdb}
  if [ $? -ne 0 ]; then
    echo "Problem encountered initializing the ${productname} server database." | tee -a $log
    echo "Please consult the troubleshooting guide." | tee -a $log
    echo "" | tee -a $log
    echo "Exiting..." | tee -a $log
    echo "" | tee -a $log
    exit 1
  fi  
else 
  echo "" | tee -a $log
  echo "${productname} server database (PostgreSQL) already initialized:" | tee -a $log
  echo "location: ${vpwdb}" | tee -a $log
fi

# Update pg_hba.conf with allowable connection info
# Many ways to get ip address on Solaris, what works for other UNIX flavors?:
# /usr/bin/netstat -in | grep hme0 | awk '{print $4}'
# /usr/bin/ping -s -n `hostname` 10 1 | grep 'bytes from' | awk '{print $5}'` | tr -d '():'
# /usr/sbin/arp `hostname` | tr -d '()' | awk '{print $2}'
# /usr/sbin/ifconfig -a | grep inet | grep -v 127.0.0.1 |awk '{print $2}'
if [ ! -f ${vpwdb}/pg_hba.conf.orig -o ! -f ${vpwdb}/pg_hba.conf ]; then
  # Let's make the admin one machine and the server more than one
  maskadmin="255.255.255.255"
  maskserver="255.255.255.0"
  echo "" | tee -a $log
  echo "Enabling ${productname} server database allowable TCP/IP connections." | tee -a $log

  # Keep the contents of the original file:
  if [ ! -f ${vpwdb}/pg_hba.conf.orig -a -f ${vpwdb}/pg_hba.conf ]; then
     mv -f ${vpwdb}/pg_hba.conf ${vpwdb}/pg_hba.conf.orig
  fi

  # Create trust file:
  cat << EOF > ${vpwdb}/pg_hba.conf.trust
#local unix sockets
local  all  trust
#Webtop Admin, Server and anything else!!:
host  all  0.0.0.0  0.0.0.0  trust
EOF

# Use the trust file, but warn user below
cp -f ${vpwdb}/pg_hba.conf.trust ${vpwdb}/pg_hba.conf

  # Create the password file with desired ip addresses:
  cat << EOF > ${vpwdb}/pg_hba.conf.pword
#local unix sockets
local  all  trust
#Webtop Admin:
host  all  $ipadmin  $maskadmin  password
#${productname} Server:
host  all  $ipserver  $maskserver  password
EOF

else
  # make it easy on ourselves :-)
  if [ -f ${vpwdb}/pg_hba.conf.trust ]; then
    cp -f ${vpwdb}/pg_hba.conf.trust ${vpwdb}/pg_hba.conf
  fi
fi
echo "Database access permissions," | tee -a $log
echo "[location: ${vpwdb}/pg_hba.conf]:" | tee -a $log
cat ${vpwdb}/pg_hba.conf | tee -a $log

# Start up the database
echo "" | tee -a $log
if [ "$pmpid" = "" ]; then
  echo "Trying to start up postmaster..." | tee -a $log
  echo $pgstart | tee -a $log
  eval $pgstart
  if [ $? -ne 0 ]; then
    echo "Problem encountered starting the ${productname} server database (PostgreSQL)." | tee -a $log
    echo "Please consult the troubleshooting guide." | tee -a $log
    echo "" | tee -a $log
    echo "Exiting..." | tee -a $log
    echo "" | tee -a $log
    exit 1
  fi
else
  echo "PostgreSQL database server is running. Stopping and restarting..." | tee -a $log
  eval $pgstop
  #echo "DEBUG: stop status = $?"
  #echo "DEBUG: ignore stop errors, starting..."

  eval $pgstart
  if [ $? -ne 0 ]; then
    echo "Problem encountered starting the ${productname} server database (PostgreSQL)." | tee -a $log
    echo "Please consult the troubleshooting guide." | tee -a $log
    echo "" | tee -a $log
    echo "Exiting..." | tee -a $log
    echo "" | tee -a $log
    exit 1
  fi
fi
echo "PostgreSQL database server is running." | tee -a $log

# Create the datbase User
echo "" | tee -a $log
sql="select usename from pg_shadow where usename='${dbuser}'"
exists=`${pgbin}/psql $dbserver -d template1 -c "$sql" | grep row | tr -d '()' | awk '{print $1}'`
if [ "$exists" = "" ]; then
  exists=0
fi
if [ $exists -ne 0 ]; then
  echo "${productname} server database user ($dbuser) already exists." | tee -a $log
else
  echo "Creating ${productname} server database user" | tee -a $log
  echo ${pgbin}/createuser -d -A ${dbserver} ${dbuser} | tee -a $log
  ${pgbin}/createuser -d -A ${dbserver} ${dbuser}
  if [ $? -ne 0 ]; then
    echo "Problem encountered creating ${productname} database user." | tee -a $log
    echo "Please consult the troubleshooting guide." | tee -a $log
    echo "" | tee -a $log
    echo "Exiting..." | tee -a $log
    echo "" | tee -a $log
    exit 1
  fi
fi

# Create each database
echo "" | tee -a $log
sql="select datname from pg_database where datname like '${dbname}%'"
exists=`${pgbin}/psql $dbserver -d template1 -c "$sql" | grep row | tr -d '()' | awk '{print $1}'`
if [ "$exists" = "" ]; then
  exists=0
fi
if [ $exists -ne 0 ]; then
  echo "${productname} server database ($dbnamesrv) already exists." | tee -a $log
else
  echo "Creating ${productname} server database: $dbnamesrv" | tee -a $log
  echo ${pgbin}/createdb $dbserver -U $dbuser $dbnamesrv "${productname} Server DB" | tee -a $log
  ${pgbin}/createdb $dbserver -U $dbuser $dbnamesrv "${productname} Server DB"
  if [ $? -ne 0 ]; then
    echo "Problem encountered creating the ${productname} server database." | tee -a $log
    echo "Please consult the troubleshooting guide." | tee -a $log
    echo "" | tee -a $log
    echo "Exiting..." | tee -a $log
    echo "" | tee -a $log
    exit 1
  fi
  # Assume that if the above worked the rest will work...
  if [ "${webtop_dir}" = "webtop" ]; then
    echo "Creating ${productname} logging database: $dbnamelog" | tee -a $log
    ${pgbin}/createdb $dbserver -U $dbuser $dbnamelog "${productname} Logging DB"
    echo "Creating ${productname} statistics database: $dbnamesta" | tee -a $log
    ${pgbin}/createdb $dbserver -U $dbuser $dbnamesta "${productname} Statistics DB"
  fi
fi

# Populate the Webtop server database
echo "" | tee -a $log
if [ $exists -ne 0 ]; then
  echo "Removing old tables and recreating them for: $dbnamesrv" | tee -a $log
  if [ "$usehpecho" = "yes" ]; then
    echo "OK [yes]? \c" | tee -a $log
  else 
    echo -n "OK [yes]? " | tee -a $log
  fi
  read item
  echo $item >> $log
  case "$item" in
    y|yes|"") echo "Continuing..." | tee -a $log; ;;
    *) echo "Exiting..."  | tee -a $log; exit 1; ;;
  esac
  echo ${pgbin}/psql $dbserver -f ${vpwpg}/pgdbdrop.sql $dbnamesrv $dbuser
  ${pgbin}/psql $dbserver -f ${vpwpg}/pgdbdrop.sql $dbnamesrv $dbuser
  if [ $? -ne 0 ]; then
    echo "Problem encountered removing the ${productname} server database tables." | tee -a $log
    echo "Please consult the troubleshooting guide." | tee -a $log
    echo "" | tee -a $log
    echo "Exiting..." | tee -a $log
    echo "" | tee -a $log
    exit 1
  fi
fi

echo "Populating ${productname} server database: $dbnamesrv" | tee -a $log
echo "using file: ${vpwpg}/pgdb.sql" | tee -a $log
echo ${pgbin}/psql $dbserver -f ${vpwpg}/pgdb.sql $dbnamesrv $dbuser | tee -a $log
${pgbin}/psql $dbserver -f ${vpwpg}/pgdb.sql $dbnamesrv $dbuser
if [ $? -ne 0 ]; then
  echo "Problem encountered populating the ${productname} server database." | tee -a $log
  echo "Please consult the troubleshooting guide." | tee -a $log
  echo "" | tee -a $log
  echo "Exiting..." | tee -a $log
  echo "" | tee -a $log
  exit 1
fi
# Assume that if the above worked the rest will work...
echo ${pgbin}/psql $dbserver -f ${vpwpg}/pgvalues.sql $dbnamesrv $dbuser | tee -a $log
${pgbin}/psql $dbserver -f ${vpwpg}/pgvalues.sql $dbnamesrv $dbuser
if [ $? -ne 0 ]; then
  echo "Problem encountered inserting values into the ${productname} server database." | tee -a $log
  echo "continuing..." | tee -a $log
  echo "" | tee -a $log
fi

# Add in the Webtop server password
echo "" | tee -a $log
echo "Updating ${productname} server database password information." | tee -a $log
echo ${pgbin}/psql $dbserver -c "update pg_shadow set passwd='${dbpasswd}' where usename='${dbuser}'" $dbnamesrv | tee -a $log
${pgbin}/psql $dbserver -c "update pg_shadow set passwd='${dbpasswd}' where usename='${dbuser}'" $dbnamesrv

# Stop it for now, since we started with minimum size
eval $pgstop

################
# SUCCESS
################
echo "" | tee -a $log
echo "Success, the PostgreSQL database has been configured. The database" | tee -a $log
echo "server is currently stopped. For info on how to start, type:" | tee -a $log
echo "   $pgbin/$thisScript --help $productalias" | tee -a $log
echo "" | tee -a $log

# WARN admin about password file for Admin and JSP connections:
echo "                ********** WARNING ********** " | tee -a $log
echo "The ${productname} server database access file is set to trust connections" | tee -a $log
echo "from any ip address. Modify the following file if you would like" | tee -a $log
if [ "${webtop_dir}" = "webtop" ]; then
  echo "to restrict access to allow only the Webtop Administration tool" | tee -a $log
  echo "and ${productname} server files. See associated '.orig' and '.pword' files" | tee -a $log
  echo "for more information and examples. File location:" | tee -a $log
else
  echo "to restrict access to allow only the ${productname} server files." | tee -a $log 
  echo "See associated '.orig' and '.pword' files for more information" | tee -a $log
  echo "and examples. File location:" | tee -a $log
fi
echo "    ${vpwdb}/pg_hba.conf" | tee -a $log
echo "                ********** ******* ********** " | tee -a $log

echo "" | tee -a $log

exit 0

